==> gridsome-source-shopify-0.2.4.tgz: package/lib/index.js <==
'use strict';

var camelCase = require('camelcase');
var nanoid = require('nanoid');
var got = require('got');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var camelCase__default = /*#__PURE__*/_interopDefaultLegacy(camelCase);
var got__default = /*#__PURE__*/_interopDefaultLegacy(got);

const ARTICLES_QUERY = `
  query Articles ($first: Int!, $after: String) {
    data: articles (first: $first, after: $after) {
      pageInfo {
        hasNextPage
      }
      edges {
        cursor
        node {
          author: authorV2 {
            bio
            email
            firstName
            lastName
            name
          }
          blog {
            id
          }
          comments(first: 250) {
            edges {
              node {
                author {
                  email
                  name
                }
                content
                contentHtml
                id
              }
            }
          }
          content
          contentHtml
          excerpt
          excerptHtml
          handle
          id
          image {
            altText
            id
            originalSrc
          }
          publishedAt
          seo {
            description
            title
          }
          tags
          title
          url
        }
      }
    }
  }
`;

const BLOGS_QUERY = `
  query Blogs ($first: Int!, $after: String) {
    data: blogs(first: $first, after: $after) {
      pageInfo {
        hasNextPage
      }
      edges {
        cursor
        node {
          authors {
            email
          }
          handle
          id
          title
          url
        }
      }
    }
  }
`;

const COLLECTIONS_QUERY = `
  query Collections ($first: Int!, $after: String) {
    data: collections (first: $first, after: $after) {
      pageInfo {
        hasNextPage
      }
      edges {
        typeName: __typename
        cursor
        node {
          description
          descriptionHtml
          handle
          id
          image {
            altText
            id
            originalSrc
          }
          products (sortKey: COLLECTION_DEFAULT, first: $first) {
            pageInfo {
              hasNextPage
            }
            edges {
              cursor
              node {
                id
              }
            }
          }
          title
          updatedAt
        }
      }
    }
  }
`;

const COLLECTION_QUERY = `query SingleCollection ($handle: String!, $first: Int!, $after: String) {
  collection: collectionByHandle (handle: $handle) {
    products (sortKey: COLLECTION_DEFAULT, first: $first, after: $after) {
      pageInfo {
        hasNextPage
      }
      edges {
        cursor
        node {
          id
        }
      }
    }
  }
}`;

const PRODUCTS_QUERY = `
  query Products ($first: Int!, $after: String) {
    data: products (first: $first, after: $after) {
      pageInfo {
        hasNextPage
      }
      edges {
        cursor
        node {
          collections (first: $first) {
            edges {
              node {
                id
              }
            }
          }
          images(first: 250) {
            edges {
              node {
                id
                altText
                originalSrc
              }
            }
          }
          variants(first: 250) {
            edges {
              node {
                availableForSale
                compareAtPrice: compareAtPriceV2 {
                  amount
                  currencyCode
                }
                id
                image {
                  altText
                  id
                  originalSrc
                }
                metafields(first: 250) {
                  edges {
                    node {
                      key
                      value
                    }
                  }
                }
                price: priceV2 {
                  amount
                  currencyCode
                }
                requiresShipping
                selectedOptions {
                  name
                  value
                }
                sku
                title
                unitPrice {
                  amount
                  currencyCode
                }
                weight
                weightUnit
              }
            }
          }
          availableForSale
          compareAtPriceRange {
            minVariantPrice {
              amount
              currencyCode
            }
            maxVariantPrice {
              amount
              currencyCode
            }
          }
          createdAt
          description
          descriptionHtml
          handle
          id
          metafields(first: 250) {
            edges {
              node {
                key
                value
              }
            }
          }
          onlineStoreUrl
          options {
            id
            name
            values
          }
          priceRange {
            minVariantPrice {
              amount
              currencyCode
            }
            maxVariantPrice {
              amount
              currencyCode
            }
          }
          productType
          publishedAt
          tags
          title
          updatedAt
          vendor
        }
      }
    }
  }
`;

const PRODUCT_TYPES_QUERY = `
  query ProductTypes ($first: Int!) {
    data: productTypes(first: $first) {
      pageInfo {
        hasNextPage
      }
      edges {
        cursor
        node
      }
    }
  }
`;
const PRODUCT_TAGS_QUERY = `
  query ProductTags ($first: Int!) {
    data: productTags(first: $first) {
      pageInfo {
        hasNextPage
      }
      edges {
        cursor
        node
      }
    }
  }
`;

const PAGES_QUERY = `
  query Pages ($first: Int!) {
    data: pages (first: $first) {
      pageInfo {
        hasNextPage
      }
      edges {
        cursor
        node {
          body
          bodySummary
          createdAt
          handle
          id
          title
          updatedAt
        }
      }
    }
  }
`;

/**
 * Create a Shopify Storefront GraphQL client for the provided name and token.
 */
const createClient = ({ storeUrl, storefrontToken, timeout }) => got__default['default'].extend({
  prefixUrl: `${storeUrl}/api/2020-10`,
  headers: {
    'X-Shopify-Storefront-Access-Token': storefrontToken
  },
  resolveBodyOnly: true,
  responseType: 'json',
  retry: 2,
  timeout
});

/**
 * Get all paginated data from a query. Will execute multiple requests as
 * needed.
 */
const queryAll = async (client, query, variables) => {
  const items = client.paginate.each('graphql.json', {
    method: 'POST',
    json: { query, variables },
    pagination: {
      backoff: 1000,
      transform: ({ body: { data, errors } }) => {
        if (errors) return []
        return data.data.edges
      },
      paginate: (response, allItems, currentItems) => {
        const { errors, data } = response.body;
        if (errors) throw new Error(errors[ 0 ].message)

        const { pageInfo } = data.data;
        if (!pageInfo.hasNextPage) return false

        const lastItem = currentItems[ currentItems.length - 1 ];
        const newVariables = { ...variables, after: lastItem.cursor };

        return {
          json: { query, variables: newVariables }
        }
      }
    }
  });

  const allNodes = [];
  for await (const { node, typeName } of items) {
    if (typeName !== 'CollectionEdge') {
      allNodes.push(node);
      continue
    }

    // Currently setup for Collection.products field, but can extend this method in future, if needed
    if (!node.products.pageInfo.hasNextPage) {
      allNodes.push(node);
      continue
    }

    const lastProduct = node.products.edges[ node.products.edges.length - 1 ];
    const collectionVariables = { ...variables, handle: node.handle, after: lastProduct.cursor };

    const remainingProducts = await client.paginate.all('graphql.json', {
      method: 'POST',
      json: { query: COLLECTION_QUERY, variables: collectionVariables },
      pagination: {
        backoff: 1000,
        transform: ({ body: { data, errors } }) => {
          if (errors) return []
          return data.collection.products.edges
        },
        paginate: (response, allItems, currentItems) => {
          const { errors, data } = response.body;
          if (errors) throw new Error(errors[ 0 ].message)

          const { pageInfo } = data.collection.products;
          if (!pageInfo.hasNextPage) return false

          const lastItem = currentItems[ currentItems.length - 1 ];
          const newVariables = { ...collectionVariables, after: lastItem.cursor };

          return {
            json: { query: COLLECTION_QUERY, variables: newVariables }
          }
        }
      }
    });

    const edges = [...node.products.edges, ...remainingProducts];
    allNodes.push({ ...node, products: { edges } });
  }

  return allNodes
};

const createSchema = ({ addSchemaTypes, schema, addSchemaResolvers }, { TYPENAMES }) => {
  addSchemaTypes([
    schema.createEnumType({
      name: `${TYPENAMES.IMAGE}CropMode`,
      values: {
        CENTER: {},
        TOP: {},
        LEFT: {},
        BOTTOM: {},
        RIGHT: {}
      }
    }),
    schema.createObjectType({
      name: TYPENAMES.IMAGE,
      interfaces: ['Node'],
      fields: {
        altText: 'String',
        originalSrc: 'String',
        transformedSrc: 'String'
      }
    }),
    schema.createObjectType({
      name: TYPENAMES.PRICE,
      interfaces: ['Node'],
      fields: {
        amount: 'String',
        currencyCode: 'String'
      }
    })
  ]);
  addSchemaResolvers({
    [ TYPENAMES.IMAGE ]: {
      transformedSrc: {
        args: {
          maxWidth: 'Int',
          maxHeight: 'Int',
          crop: `${TYPENAMES.IMAGE}CropMode`,
          scale: 'Int'
        },
        resolve ({ originalSrc }, { maxHeight, maxWidth, crop, scale }) {
          // Create the transform for Shopify CDN
          const dot = originalSrc.lastIndexOf('.');
          const path = originalSrc.slice(0, dot);
          const ext = originalSrc.slice(dot);
          const transforms = [];

          if (maxWidth && maxHeight) transforms.push(`_${maxWidth}x${maxHeight}`);
          else if (maxWidth) transforms.push(`_${maxWidth}x`);
          else if (maxHeight) transforms.push(`_x${maxHeight}`);

          if (crop && (maxWidth || maxHeight)) transforms.push(`_crop_${crop.toLowerCase()}`);
          if (scale && scale !== 1) transforms.push(`@${scale}x`);

          const transformedSrc = `${path}${transforms.join('')}${ext}`;
          return transformedSrc
        }
      }
    },
    [ TYPENAMES.PRICE ]: {
      amount: {
        args: {
          locale: 'String',
          currency: 'String',
          format: 'Boolean'
        },
        resolve: ({ amount, currencyCode }, { locale = 'en-US', currency, format = false }) => {
          if (!currency && !format) return amount
          return new Intl.NumberFormat(locale, { style: 'currency', currency: currency || currencyCode }).format(amount)
        }
      }
    }
  });
};

class ShopifySource {
  static defaultOptions () {
    return {
      storeName: '',
      storeUrl: '',
      storefrontToken: '',
      typeName: 'Shopify',
      types: [],
      perPage: 100,
      timeout: 60000
    }
  }

  constructor (api, options) {
    this.options = options;

    if (!options.storeUrl && !options.storeName) throw new Error('Missing store name or url.')
    if (!options.storefrontToken) throw new Error('Missing storefront access token.')
    if (options.storeName) this.options.storeUrl = `https://${options.storeName}.myshopify.com`;

    // Node Types
    this.TYPENAMES = {
      ARTICLE: this.createTypeName('Article'),
      BLOG: this.createTypeName('Blog'),
      COLLECTION: this.createTypeName('Collection'),
      PRODUCT: this.createTypeName('Product'),
      PRODUCT_VARIANT: this.createTypeName('ProductVariant'),
      PAGE: this.createTypeName('Page'),
      PRODUCT_TYPE: this.createTypeName('ProductType'),
      PRODUCT_TAG: this.createTypeName('ProductTag'),
      IMAGE: 'ShopifyImage',
      PRICE: 'ShopifyPrice'
    };

    // Set included types
    this.typesToInclude = options.types.length ? options.types.map(type => this.createTypeName(type)) : Object.values(this.TYPENAMES);

    this.shopify = createClient(options);

    // Create custom schema type for ShopifyImage
    api.loadSource(actions => {
      createSchema(actions, { TYPENAMES: this.TYPENAMES });
    });

    // Load data into store
    api.loadSource(async actions => {
      console.log(`Loading data from ${options.storeUrl}`);

      await this.setupStore(actions);
      await this.getProductTypes(actions);
      await this.getProductTags(actions);
      await this.getCollections(actions);
      await this.getProducts(actions);
      await this.getBlogs(actions);
      await this.getArticles(actions);
      await this.getPages(actions);
    });
  }

  async setupStore (actions) {
    actions.addCollection({ typeName: this.TYPENAMES.PRICE });
    actions.addCollection({ typeName: this.TYPENAMES.IMAGE });
  }

  async getProductTypes (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.PRODUCT_TYPE)) return

    const productTypeStore = actions.addCollection({ typeName: this.TYPENAMES.PRODUCT_TYPE });

    const allProductTypes = await queryAll(this.shopify, PRODUCT_TYPES_QUERY, { first: this.options.perPage });

    for (const productType of allProductTypes) {
      if (productType) productTypeStore.addNode({ title: productType });
    }
  }

  async getProductTags (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.PRODUCT_TAG)) return

    const productTagStore = actions.addCollection({ typeName: this.TYPENAMES.PRODUCT_TAG });

    const allProductTags = await queryAll(this.shopify, PRODUCT_TAGS_QUERY, { first: this.options.perPage });

    for (const productTag of allProductTags) {
      if (productTag) productTagStore.addNode({ title: productTag });
    }
  }

  async getCollections (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.COLLECTION)) return

    const imageStore = actions.getCollection(this.TYPENAMES.IMAGE);
    const collectionStore = actions.addCollection({ typeName: this.TYPENAMES.COLLECTION });

    const allCollections = await queryAll(this.shopify, COLLECTIONS_QUERY, { first: this.options.perPage });

    for (const collection of allCollections) {
      collection.products = collection.products.edges.map(({ node: product }) => actions.createReference(this.TYPENAMES.PRODUCT, product.id));

      if (collection.image) {
        const collectionImage = imageStore.addNode(collection.image);
        collection.image = actions.createReference(collectionImage);
      }

      collectionStore.addNode(collection);
    }
  }

  async getProducts (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.PRODUCT)) return

    const productStore = actions.addCollection({ typeName: this.TYPENAMES.PRODUCT });
    const productVariantStore = actions.addCollection({ typeName: this.TYPENAMES.PRODUCT_VARIANT });
    const imageStore = actions.getCollection(this.TYPENAMES.IMAGE);
    const priceStore = actions.getCollection(this.TYPENAMES.PRICE);

    const allProducts = await queryAll(this.shopify, PRODUCTS_QUERY, { first: this.options.perPage });

    for (const product of allProducts) {
      product.collections = product.collections.edges.map(({ node: collection }) => actions.createReference(this.TYPENAMES.COLLECTION, collection.id));

      const priceRange = this.getProductPriceRanges(product.priceRange, actions);
      const compareAtPriceRange = this.getProductPriceRanges(product.compareAtPriceRange, actions);

      const images = product.images.edges.map(({ node: image }) => {
        const productImage = imageStore.addNode(image);
        return actions.createReference(productImage)
      });

      const variants = product.variants.edges.map(({ node: variant }) => {
        if (variant.image) {
          variant.image = actions.createReference(this.TYPENAMES.IMAGE, variant.image.id);
        }

        const price = priceStore.addNode({ id: nanoid.nanoid(), ...variant.price });
        variant.price = actions.createReference(price);

        const unitPrice = priceStore.addNode({ id: nanoid.nanoid(), ...variant.unitPrice });
        variant.unitPrice = actions.createReference(unitPrice);

        const compareAtPrice = priceStore.addNode({ id: nanoid.nanoid(), ...variant.compareAtPrice });
        variant.compareAtPrice = actions.createReference(compareAtPrice);

        const variantNode = productVariantStore.addNode(variant);
        return actions.createReference(variantNode)
      });

      productStore.addNode({
        ...product,
        priceRange,
        compareAtPriceRange,
        variants,
        images
      });
    }
  }

  getProductPriceRanges (priceRange, actions) {
    const priceStore = actions.getCollection(this.TYPENAMES.PRICE);

    const minVariantPrice = priceStore.addNode({ id: nanoid.nanoid(), ...priceRange.minVariantPrice });
    const maxVariantPrice = priceStore.addNode({ id: nanoid.nanoid(), ...priceRange.maxVariantPrice });

    return { minVariantPrice: actions.createReference(minVariantPrice), maxVariantPrice: actions.createReference(maxVariantPrice) }
  }

  async getBlogs (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.BLOG)) return

    const blogStore = actions.addCollection({ typeName: this.TYPENAMES.BLOG });

    const allBlogs = await queryAll(this.shopify, BLOGS_QUERY, { first: this.options.perPage });

    for (const blog of allBlogs) {
      blogStore.addNode(blog);
    }
  }

  async getArticles (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.ARTICLE)) return

    const articleStore = actions.addCollection({ typeName: this.TYPENAMES.ARTICLE });
    const imageStore = actions.getCollection(this.TYPENAMES.IMAGE);

    const allArticles = await queryAll(this.shopify, ARTICLES_QUERY, { first: this.options.perPage });

    for (const article of allArticles) {
      if (article.image) {
        const articleImage = imageStore.addNode(article.image);
        article.image = actions.createReference(articleImage);
      }

      if (this.typesToInclude.includes(this.TYPENAMES.BLOG)) {
        article.blog = actions.createReference(this.TYPENAMES.BLOG, article.blog.id);
      }

      articleStore.addNode(article);
    }
  }

  async getPages (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.PAGE)) return

    const pageStore = actions.addCollection({ typeName: this.TYPENAMES.PAGE });

    const allPages = await queryAll(this.shopify, PAGES_QUERY, { first: this.options.perPage });

    for (const page of allPages) {
      pageStore.addNode(page);
    }
  }

  createTypeName (name) {
    let typeName = this.options.typeName;
    // If typeName is blank, we need to add a preifx to these types anyway, as on their own they conflict with internal Gridsome types.
    const types = ['Page'];
    if (!typeName && types.includes(name)) typeName = 'Shopify';

    return camelCase__default['default'](`${typeName} ${name}`, { pascalCase: true })
  }
}

module.exports = ShopifySource;

==> gridsome-source-shopify-0.2.5.tgz: package/lib/index.js <==
'use strict';

var camelCase = require('camelcase');
var nanoid = require('nanoid');
require('got');
var queries = require('./queries.js');
var client = require('./client.js');
var schema = require('./schema.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var camelCase__default = /*#__PURE__*/_interopDefaultLegacy(camelCase);

class ShopifySource {
  static defaultOptions () {
    return {
      storeName: '',
      storeUrl: '',
      storefrontToken: '',
      typeName: 'Shopify',
      types: [],
      perPage: 100,
      timeout: 60000
    }
  }

  constructor (api, options) {
    this.options = options;

    if (!options.storeUrl && !options.storeName) throw new Error('Missing store name or url.')
    if (!options.storefrontToken) throw new Error('Missing storefront access token.')
    if (options.storeName) this.options.storeUrl = `https://${options.storeName}.myshopify.com`;

    // Node Types
    this.TYPENAMES = {
      ARTICLE: this.createTypeName('Article'),
      BLOG: this.createTypeName('Blog'),
      COLLECTION: this.createTypeName('Collection'),
      PRODUCT: this.createTypeName('Product'),
      PRODUCT_VARIANT: this.createTypeName('ProductVariant'),
      PAGE: this.createTypeName('Page'),
      PRODUCT_TYPE: this.createTypeName('ProductType'),
      PRODUCT_TAG: this.createTypeName('ProductTag'),
      IMAGE: 'ShopifyImage',
      PRICE: 'ShopifyPrice'
    };

    // Set included types
    this.typesToInclude = options.types.length ? options.types.map(type => this.createTypeName(type)) : Object.values(this.TYPENAMES);

    this.shopify = client.createClient(options);

    // Create custom schema type for ShopifyImage
    api.loadSource(actions => {
      schema.createSchema(actions, { TYPENAMES: this.TYPENAMES });
    });

    // Load data into store
    api.loadSource(async actions => {
      console.log(`Loading data from ${options.storeUrl}`);

      await this.setupStore(actions);
      await this.getProductTypes(actions);
      await this.getProductTags(actions);
      await this.getCollections(actions);
      await this.getProducts(actions);
      await this.getBlogs(actions);
      await this.getArticles(actions);
      await this.getPages(actions);
    });
  }

  async setupStore (actions) {
    actions.addCollection({ typeName: this.TYPENAMES.PRICE });
    actions.addCollection({ typeName: this.TYPENAMES.IMAGE });
  }

  async getProductTypes (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.PRODUCT_TYPE)) return

    const productTypeStore = actions.addCollection({ typeName: this.TYPENAMES.PRODUCT_TYPE });

    const allProductTypes = await client.queryAll(this.shopify, queries.PRODUCT_TYPES_QUERY, { first: this.options.perPage });

    for (const productType of allProductTypes) {
      if (productType) productTypeStore.addNode({ title: productType });
    }
  }

  async getProductTags (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.PRODUCT_TAG)) return

    const productTagStore = actions.addCollection({ typeName: this.TYPENAMES.PRODUCT_TAG });

    const allProductTags = await client.queryAll(this.shopify, queries.PRODUCT_TAGS_QUERY, { first: this.options.perPage });

    for (const productTag of allProductTags) {
      if (productTag) productTagStore.addNode({ title: productTag });
    }
  }

  async getCollections (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.COLLECTION)) return

    const imageStore = actions.getCollection(this.TYPENAMES.IMAGE);
    const collectionStore = actions.addCollection({ typeName: this.TYPENAMES.COLLECTION });

    const allCollections = await client.queryAll(this.shopify, queries.COLLECTIONS_QUERY, { first: this.options.perPage });

    for (const collection of allCollections) {
      collection.products = collection.products.edges.map(({ node: product }) => actions.createReference(this.TYPENAMES.PRODUCT, product.id));

      if (collection.image) {
        const collectionImage = imageStore.addNode(collection.image);
        collection.image = actions.createReference(collectionImage);
      }

      collectionStore.addNode(collection);
    }
  }

  async getProducts (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.PRODUCT)) return

    const productStore = actions.addCollection({ typeName: this.TYPENAMES.PRODUCT });
    const productVariantStore = actions.addCollection({ typeName: this.TYPENAMES.PRODUCT_VARIANT });
    const imageStore = actions.getCollection(this.TYPENAMES.IMAGE);
    const priceStore = actions.getCollection(this.TYPENAMES.PRICE);

    const allProducts = await client.queryAll(this.shopify, queries.PRODUCTS_QUERY, { first: this.options.perPage });

    for (const product of allProducts) {
      product.collections = product.collections.edges.map(({ node: collection }) => actions.createReference(this.TYPENAMES.COLLECTION, collection.id));

      const priceRange = this.getProductPriceRanges(product.priceRange, actions);
      const compareAtPriceRange = this.getProductPriceRanges(product.compareAtPriceRange, actions);

      const images = product.images.edges.map(({ node: image }) => {
        const productImage = imageStore.addNode(image);
        return actions.createReference(productImage)
      });

      const variants = product.variants.edges.map(({ node: variant }) => {
        if (variant.image) {
          variant.image = actions.createReference(this.TYPENAMES.IMAGE, variant.image.id);
        }

        const price = priceStore.addNode({ id: nanoid.nanoid(), ...variant.price });
        variant.price = actions.createReference(price);

        const unitPrice = priceStore.addNode({ id: nanoid.nanoid(), ...variant.unitPrice });
        variant.unitPrice = actions.createReference(unitPrice);

        const compareAtPrice = priceStore.addNode({ id: nanoid.nanoid(), ...variant.compareAtPrice });
        variant.compareAtPrice = actions.createReference(compareAtPrice);

        const variantNode = productVariantStore.addNode(variant);
        return actions.createReference(variantNode)
      });

      productStore.addNode({
        ...product,
        priceRange,
        compareAtPriceRange,
        variants,
        images
      });
    }
  }

  getProductPriceRanges (priceRange, actions) {
    const priceStore = actions.getCollection(this.TYPENAMES.PRICE);

    const minVariantPrice = priceStore.addNode({ id: nanoid.nanoid(), ...priceRange.minVariantPrice });
    const maxVariantPrice = priceStore.addNode({ id: nanoid.nanoid(), ...priceRange.maxVariantPrice });

    return { minVariantPrice: actions.createReference(minVariantPrice), maxVariantPrice: actions.createReference(maxVariantPrice) }
  }

  async getBlogs (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.BLOG)) return

    const blogStore = actions.addCollection({ typeName: this.TYPENAMES.BLOG });

    const allBlogs = await client.queryAll(this.shopify, queries.BLOGS_QUERY, { first: this.options.perPage });

    for (const blog of allBlogs) {
      blogStore.addNode(blog);
    }
  }

  async getArticles (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.ARTICLE)) return

    const articleStore = actions.addCollection({ typeName: this.TYPENAMES.ARTICLE });
    const imageStore = actions.getCollection(this.TYPENAMES.IMAGE);

    const allArticles = await client.queryAll(this.shopify, queries.ARTICLES_QUERY, { first: this.options.perPage });

    for (const article of allArticles) {
      if (article.image) {
        const articleImage = imageStore.addNode(article.image);
        article.image = actions.createReference(articleImage);
      }

      if (this.typesToInclude.includes(this.TYPENAMES.BLOG)) {
        article.blog = actions.createReference(this.TYPENAMES.BLOG, article.blog.id);
      }

      articleStore.addNode(article);
    }
  }

  async getPages (actions) {
    if (!this.typesToInclude.includes(this.TYPENAMES.PAGE)) return

    const pageStore = actions.addCollection({ typeName: this.TYPENAMES.PAGE });

    const allPages = await client.queryAll(this.shopify, queries.PAGES_QUERY, { first: this.options.perPage });

    for (const page of allPages) {
      pageStore.addNode(page);
    }
  }

  createTypeName (name) {
    let typeName = this.options.typeName;
    // If typeName is blank, we need to add a preifx to these types anyway, as on their own they conflict with internal Gridsome types.
    const types = ['Page'];
    if (!typeName && types.includes(name)) typeName = 'Shopify';

    return camelCase__default['default'](`${typeName} ${name}`, { pascalCase: true })
  }
}

module.exports = ShopifySource;
